
"""
"""

__version__ = '0.1.145'

# flake8: noqa

from wheezy.routing.router import PathRouter
from wheezy.routing.router import url
